( cd usr/lib64 ; rm -rf libenchant.so )
( cd usr/lib64 ; ln -sf libenchant.so.1.4.2 libenchant.so )
( cd usr/lib64 ; rm -rf libenchant.so.1 )
( cd usr/lib64 ; ln -sf libenchant.so.1.4.2 libenchant.so.1 )
